import pandas as pd
from tabulate import tabulate
from IPython.display import display, HTML
import os
import json

# Set global display options
pd.set_option('display.max_colwidth', None)
pd.set_option('display.width', None)

# Function to convert nested dictionary to DataFrame
def dict_to_dataframe(data, fmt='{:,.3g}', transpose = False):
    for exp in data:
        for metric in data[exp]:
            try:
                data[exp][metric] = fmt.format(data[exp][metric])
            except:
                pass
    df = pd.DataFrame(data).T
    if transpose:
        df = df.T
    return df

# Function to convert DataFrame to LaTeX
def to_latex(data, fmt='{:,.3g}', transpose=False, escape=None):
    df = dict_to_dataframe(data, fmt = fmt, transpose = transpose)
    latex_code = df.to_latex(escape=escape)
    
    # Fit the LaTeX table into the template
    table_tmp = """\\begin{table}[t]
    \\centering
    \\scriptsize
    
    %s
    
    \caption{Caption Title.}
    \label{tab:tablename}
    \end{table}
    """
    return table_tmp % latex_code

# Function to convert DataFrame to Markdown
def to_markdown(data, fmt='{:,.3g}', transpose=False):
    df = dict_to_dataframe(data, fmt = fmt, transpose = transpose)
    markdown_table = tabulate(df, tablefmt="pipe", headers="keys")
    return markdown_table

# Function to display DataFrame in Jupyter
def show(data, fmt='{:,.3g}', transpose=False):
    df = dict_to_dataframe(data, fmt = fmt, transpose = transpose)
    display(HTML(df.to_html()))

def read_results(baseurl, expnames, filename="eval.json"):
    results = {}
    if isinstance(expnames, list):
        for expname in expnames:
            filepath = os.path.join(baseurl, expname, filename)
            if os.path.exists(filepath):
                with open(filepath, 'r') as file:
                    results[expname] = json.load(file)
            else:
                print(f"File not found: {filepath}")
    elif isinstance(expnames, dict):
        for key, value in expnames.items():
            filepath = os.path.join(baseurl, value, filename)
            if os.path.exists(filepath):
                with open(filepath, 'r') as file:
                    results[key] = json.load(file)
            else:
                print(f"File not found: {filepath}")
    else:
        print("Invalid expnames type. It should be either a list or a dict.")
    return results



import unittest
import pandas as pd
import sys
sys.path.append("expviz/")
from expviz import *

class TestTableConversion(unittest.TestCase):
    
    def setUp(self):
        self.data = {
            "exp1": {"Score1": 10.1, "Score2": "NaN"},
            "exp2": {"Score1": 30, "Score2": 40}
        }

    def test_dict_to_dataframe(self):
        df = dict_to_dataframe(self.data)
        expected_df = pd.DataFrame(self.data).T
        pd.testing.assert_frame_equal(df, expected_df)
        
    def test_to_latex(self):
        latex_code = to_latex(self.data)
        self.assertIsInstance(latex_code, str)
        self.assertIn('\\begin{table}', latex_code)
        self.assertIn('\\end{table}', latex_code)
        
    def test_to_markdown(self):
        markdown_table = to_markdown(self.data)
        self.assertIsInstance(markdown_table, str)
        self.assertTrue(markdown_table.startswith('|'))
        self.assertTrue(markdown_table.endswith('|'))
        
    def test_show(self):
        # Testing `show` function can be tricky as it doesn't return anything, 
        # it just displays the DataFrame in Jupyter. You might check if 
        # it runs without errors with different inputs.
        try:
            show(self.data)
        except Exception as e:
            self.fail(f"show raised exception {e}")

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
from setuptools import setup, find_packages

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()
from expviz.version import __version__

setup(
    name='expviz',
    version=__version__,
    description='Visualize experiments tables and figures.',
    url='https://github.com/fuzihaofzh/expviz',
    author='',
    author_email='',
    license='',
    classifiers=[
        'Programming Language :: Python :: 3.7',
    ],
    keywords='Shell env',
    packages=find_packages(),
    install_requires=[
    ],
    long_description=long_description,
    long_description_content_type='text/markdown',
    include_package_data=True
)